@@ -13,13 +13,9 @@
 curve_to_q <- function(beta){
     n = nrow(beta)
     T1 = ncol(beta)
-    v = matrix(0, n, T1)
-    for (i in 1:n){
-        v[i,] = gradient(beta[i,], 1.0/(T1-1))
-    }
+    v = apply(beta,1,gradient, 1.0/(T1-1))
+    v = t(v)
 
-#     len = sum(sqrt(colSums(v*v)))/T1
-#     v = v/len
     q = matrix(0,n,T1)
     for (i in 1:T1){
         L = sqrt(pvecnorm(v[,i],2))
