@@ -20,12 +20,14 @@
 #' @references Cheng, W., Dryden, I. L., and Huang, X. (2016). Bayesian registration of functions and curves. Bayesian Analysis, 11(2), 447-475.
 #' @references Srivastava, A., Klassen, E., Joshi, S., Jermyn, I., (2011). Shape analysis of elastic curves in euclidean spaces. Pattern Analysis and Machine Intelligence, IEEE Transactions on 33 (7), 1415-1428.
 #' @references Cheng, W., Dryden, I. L., and Huang, X. (2016). Bayesian registration of functions and curves. Bayesian Analysis, 11(2), 447-475.
+#' @references Xie, W., S. Kurtek, K. Bharath, and Y. Sun  (2016). "A Geometric Approach to Visualization of Variability in Functional Data." Journal of the American Statistical Association in press: 1-34.
 #' @docType package
-#' @useDynLib fdasrvf
+#' @useDynLib fdasrvf, .registration=TRUE
 #' @import foreach mvtnorm matrixcalc splines parallel doParallel Rcpp fields
-#' @importFrom graphics layout legend matplot plot title lines
+#' @importFrom graphics layout legend matplot plot title lines image
 #' @importFrom coda traceplot mcmc
-#' @importFrom stats approx cov optim predict quantile rnorm runif sd smooth.spline var spline
+#' @importFrom viridisLite viridis
+#' @importFrom stats approx cov optim predict quantile rnorm runif sd smooth.spline var spline median
 #' @aliases fdasrvf fdasrvf-package
 NULL
 #' Simulated two Gaussian Dataset
@@ -90,6 +92,23 @@ NULL
 #' @usage data("simu_warp")
 #' @format A list which contains the outputs of the time_warping function
 NULL
+#' Aligned Simulated two Gaussian Dataset using Median
+#'
+#' A functional dataset where the individual functions are given by:
+#' \eqn{y_i(t) = z_{i,1} e^{-(t-1.5)^2/2} + z_{i,2}e^{-(t+1.5)^2/2}}, \eqn{t \in [-3, 3], ~i=1,2,\dots, 21},
+#' where \eqn{z_{i,1}} and \eqn{z_{i,2}} are \emph{i.i.d.} normal with mean one and standard deviation
+#' 0.25. Each of these functions is then warped according to: \eqn{\gamma_i(t) = 6({e^{a_i(t+3)/6} -1 \over e^{a_i} - 1}) - 3}
+#' if  \eqn{a_i \neq 0}, otherwise \eqn{\gamma_i = \gamma_{id}} (\eqn{gamma_{id}(t) = t})
+#' is the identity warping). The variables are as follows: f containing the
+#' 21 functions of 101 samples and time which describes the sampling which has been aligned
+#'
+#'
+#' @docType data
+#' @keywords datasets
+#' @name simu_warp_median
+#' @usage data("simu_warp_median")
+#' @format A list which contains the outputs of the time_warping function finding the median
+NULL
 #' MPEG7 Curve Dataset
 #'
 #' Contains the MPEG7 curve data set which is 20 curves in 65 classes. The array
